Skip to contents

Creates a model based on a bootstrap sample of the data. Useful for assessing variability and identifying observations that are surprising relative to resampled distributions.

Usage

bs_model_bootstrap(n_bootstrap = 100, seed = NULL, name = NULL)

Arguments

n_bootstrap

Number of bootstrap samples to use

seed

Random seed for reproducibility

name

Optional name for the model

Value

A bs_model_bootstrap object

Examples

model <- bs_model_bootstrap(n_bootstrap = 100)