Visualizes the prior and posterior probabilities of a model space.
Arguments
- x
A
bs_model_spaceobject- y
Unused
- main
Plot title
- col
Colors for prior and posterior bars
- ...
Additional arguments passed to
barplot()
Visualizes the prior and posterior probabilities of a model space.
A bs_model_space object
Unused
Plot title
Colors for prior and posterior bars
Additional arguments passed to barplot()