Combines multiple models into a model space with prior probabilities. The model space represents the set of hypotheses about how data is generated.
Examples
# Create model space with uniform prior
space <- model_space(
bs_model_uniform(),
bs_model_gaussian()
)
# Create with custom prior
space <- model_space(
bs_model_uniform(),
bs_model_baserate(c(0.2, 0.3, 0.5)),
prior = c(0.3, 0.7)
)
# Create from list
models <- list(bs_model_uniform(), bs_model_gaussian())
space <- model_space(models)